# 🌞 rointe-sdk
## A python 3 library to interact with Rointe Devices.


`rointe-sdk` is a Python 3 library for the Rointe HomeAssistant integration via a REST API.

* [Installation](#Installation)
* [Supported devices] (#supported-devices)


## Installation
```bash
pip install rointe-sdk
```

## Supported devices
Currently supported devices include:
* D-Series radiators
* Belize radiators
* Olympia radiators
* Wi-Fi enabled towel rails
* Thermostat


## Contributions used
* Portions from https://github.com/bachya/pypi-template
* Portions from https://github.com/bachya/aiopurpleair

